# Beste Praktiken für Prompt Engineering mit OpenAI API

> Geschrieben von Jessica Shieh  
> https://help.openai.com/en/articles/6654000-best-practices-for-prompt-engineering-with-openai-api  
> _Daumenregeln und Beispiele_  
> Hinweis: "{text input here}" ist ein Platzhalter für den tatsächlichen Text/Kontext  

## Geben Sie Anweisungen am Anfang des Prompts an und verwenden Sie ### oder """ um die Anweisung und den Kontext abzugrenzen   
#### Weniger effektiv ❌:  
```
Fassen Sie den folgenden Text als Liste der wichtigsten Punkte zusammen.  
  
{text input here}  
```
  
### Besser ✅:  
```
Fassen Sie den folgenden Text als Liste der wichtigsten Punkte zusammen.  
  
Text: """  
{text input here}  
"""  
```
  
  
## Seien Sie spezifisch, beschreibend und so detailliert wie möglich in Bezug auf den gewünschten Kontext, das Ergebnis, die Länge, das Format, den Stil usw.  
Seien Sie spezifisch in Bezug auf den Kontext, das Ergebnis, die Länge, das Format, den Stil usw.  
#### Weniger effektiv ❌:  
```
Schreiben Sie ein Gedicht über OpenAI.  
```
  
### Besser ✅:  
```
Schreiben Sie ein kurzes inspirierendes Gedicht über OpenAI mit Fokus auf den kürzlichen DALL-E Produktstart (DALL-E ist ein Text-to-Image-ML-Modell) im Stil eines {berühmten Dichters}.  
```
  
  
## Artikulieren Sie das gewünschte Ausgabeformat durch Beispiele  
#### Weniger effektiv ❌:  
```
Extrahieren Sie die im folgenden Text erwähnten Entitäten. Extrahieren Sie die folgenden 4 Entitätstypen: Firmennamen, Personennamen, spezifische Themen und Themen.  
  
Text: {text}  
```
  
Zeigen Sie es und sagen Sie es - die Modelle reagieren besser auf spezifische Formatanforderungen. Dies erleichtert auch das programmatische Zuordnen mehrerer Ausgaben zuverlässig.  
  
### Besser ✅:  
```
Extrahieren Sie die wichtigen Entitäten aus dem folgenden Text. Zuerst extrahieren Sie alle Firmennamen, dann extrahieren Sie alle Personennamen, dann extrahieren Sie spezifische Themen, die zum Inhalt passen, und schließlich extrahieren Sie allgemeine übergreifende Themen.  
  
Gewünschtes Format:  
Firmennamen: <Kommagetrennte Liste von Firmennamen>  
Personennamen: -||-  
Spezifische Themen: -||-  
Allgemeine Themen: -||-  
  
Text: {text}  
```
## Beginnen Sie mit zero-shot, dann few-shot, wenn keiner von beiden funktioniert, dann fine-tune  
### ✅ Zero-shot    
```
Extrahieren Sie Stichwörter aus dem folgenden Text.  
  
Text: {text}  
  
Stichwörter:  
```
  
### ✅ Few-shot - geben Sie ein paar Beispiele  
```
Extrahieren Sie Stichwörter aus den folgenden Texten.  
  
Text 1: Stripe bietet APIs an, die Webentwickler verwenden können, um die Zahlungsabwicklung in ihre Websites und mobilen Anwendungen zu integrieren.  
Stichwörter 1: Stripe, Zahlungsabwicklung, APIs, Webentwickler, Websites, mobile Anwendungen  
##  
Text 2: OpenAI hat bahnbrechende Sprachmodelle trainiert, die sehr gut darin sind, Texte zu verstehen und zu generieren. Unser API ermöglicht den Zugriff auf diese Modelle und kann genutzt werden, um praktisch jede Aufgabe zu lösen, die Sprachverarbeitung involviert.  
Stichwörter 2: OpenAI, Sprachmodelle, Textverarbeitung, API.  
##  
Text 3: {text}  
Stichwörter 3:  
```
  
  
## Reduzieren Sie "fluffige" und ungenaue Beschreibungen  
#### Weniger effektiv ❌:  
```
Die Beschreibung für dieses Produkt sollte recht kurz sein, nur ein paar Sätze und nicht viel mehr.  
```
  
### Besser ✅:  
```
Verwenden Sie einen 3- bis 5-satz langen Absatz, um dieses Produkt zu beschreiben.  
```
  
  
## Anstatt nur zu sagen, was man nicht tun sollte, sagen Sie, was man stattdessen tun sollte  
#### Weniger effektiv ❌:  
```
Es folgt ein Gespräch zwischen einem Agenten und einem Kunden. FRAGEN SIE NICHT NACH BENUTZERNAME ODER PASSWORT. WIEDERHOLEN SIE NICHT.  
  
Kunde: Ich kann mich nicht in mein Konto einloggen.  
Agent:  
```
  
### Besser ✅:  
```
Es folgt ein Gespräch zwischen einem Agenten und einem Kunden. Der Agent wird versuchen, das Problem zu diagnostizieren und eine Lösung zu empfehlen, ohne Fragen im Zusammenhang mit der persönlich identifizierbaren Information (PII) des Kunden zu stellen. Verweisen Sie den Benutzer stattdessen auf den Hilfeartikel www.samplewebsite.com/help/faq.  
  
Kunde: Ich kann mich nicht in mein Konto einloggen.  
Agent:  
```
  
  
## Code-Generierung spezifisch - Verwenden Sie "führende Wörter", um das Modell in eine bestimmte Struktur zu lenken  
#### Weniger effektiv ❌:  
```
# Schreiben Sie eine einfache Python-Funktion, die  
# 1. nach einer Zahl in Meilen fragt  
# 2. Meilen in Kilometer umrechnet  
```
  
In diesem Code-Beispiel unten geben "import"-Hinweise dem Modell einen Hinweis darauf, dass es mit dem Schreiben in Python beginnen sollte. ("SELECT" ist ein ähnlich guter Hinweis für den Beginn einer SQL-Anweisung.)   
  
### Besser ✅:  
```
# Schreiben Sie eine einfache Python-Funktion, die  
# 1. nach einer Zahl in Meilen fragt  
# 2. Meilen in Kilometer umrechnet  
   
import  
```
