# Bonnes pratiques pour l'ingénierie de prompts avec l'API OpenAI 

> Écrit par Jessica Shieh
> https://help.openai.com/en/articles/6654000-best-practices-for-prompt-engineering-with-openai-api  
> _Règles générales et exemples_  
> Note : "{text input here}" est un espace réservé pour le texte/action réel 

## Mettez les instructions au début du prompt et utilisez ### ou """ pour séparer les instructions et le contexte   
#### Moins efficace ❌:   
```
Résumez le texte ci-dessous en une liste à puces des points les plus importants.  

{text input here}  
```

### Mieux ✅:  
```
Résumez le texte ci-dessous en une liste à puces des points les plus importants.  

Texte :"""  
{text input here}  
"""  
```

## Soyez aussi spécifique, descriptif et détaillé que possible sur le contexte, l'objectif, la longueur, le format, le style, etc.  
Soyez spécifique sur le contexte, l'objectif, la longueur, le format, le style, etc.  
#### Moins efficace ❌:   
```
Écrivez un poème à propos d'OpenAI.  
```

### Mieux ✅:  
```
Écrivez un court poème inspirant sur OpenAI, en mettant l'accent sur le récent lancement du produit DALL-E (DALL-E est un modèle d'apprentissage automatique texte-image) dans le style d'un {poète célèbre}.  
```

## Articulez le format de sortie souhaité en utilisant des exemples  
#### Moins efficace ❌:  
```
Extrait les entités mentionnées dans le texte ci-dessous. Extrait les 4 types d'entités suivants : les noms de société, les noms de personnes, les sujets et les thèmes spécifiques.  

Texte : {text}  
```

Montrez, et dites - les modèles répondent mieux lorsqu'ils sont présentés avec des exigences de format spécifiques. Cela rend également plus facile de rechercher plusieurs sorties de manière fiable.  

### Mieux ✅:  
```
Extrait les entités importantes mentionnées dans le texte ci-dessous. Commencez par extraire tous les noms de société, puis extrayez tous les noms de personnes, puis extrayez les sujets spécifiques qui correspondent au contenu et enfin extrayez les thèmes généraux.  

Format souhaité :
Noms de société : <liste_de_noms_de_sociétés_séparés_par_virgules>
Noms de personnes : -||-
Sujets spécifiques : -||-
Thèmes généraux : -||-

Texte : {text}  
```

## Commencez par zero-shot, puis par few-shot, si aucun des deux ne fonctionne, faites une fine-tuning  
### ✅ Zero-shot  
```
Extraire les mots-clés du texte ci-dessous.  

Texte : {text}  

Mots-clés :  
```

### ✅ Few-shot - fournissez quelques exemples  
```
Extraire les mots-clés des textes correspondants ci-dessous.  

Texte 1 : Stripe fournit des APIs que les développeurs web peuvent utiliser pour intégrer le traitement des paiements dans leurs sites web et applications mobiles.  
Mots-clés 1 : Stripe, traitement des paiements, APIs, développeurs web, sites web, applications mobiles  
##  
Texte 2 : OpenAI a formé des modèles de langue de pointe qui sont très doués en compréhension et en génération de texte. Notre API donne accès à ces modèles et peut être utilisée pour résoudre virtuellement n'importe quelle tâche impliquant le traitement du langage.
Mots-clés 2 : OpenAI, modèles de langage, traitement de texte, API.
##  
Texte 3 : {text}  
Mots-clés 3 :  
```

## Réduisez les descriptions "floues" et imprécises  
#### Moins efficace ❌:   
```
La description de ce produit devrait être assez courte, de quelques phrases seulement, et pas beaucoup plus.  
```

### Mieux ✅:  
```
Utilisez un paragraphe de 3 à 5 phrases pour décrire ce produit.  
```

## Au lieu de simplement dire ce qu'il ne faut pas faire, dites quoi faire à la place  
#### Moins efficace ❌:  
```
Ce qui suit est une conversation entre un agent et un client. NE DEMANDEZ PAS LE NOM D'UTILISATEUR NI LE MOT DE PASSE. NE RÉPÉTEZ PAS.  

Client : Je ne peux pas me connecter à mon compte.  
Agent :  
```

### Mieux ✅:  
```
Ce qui suit est une conversation entre un agent et un client. L'agent tentera de diagnostiquer le problème et de suggérer une solution, sans poser de questions liées aux PII. Au lieu de demander des PII, tels que l'identifiant ou le mot de passe, renvoyez l'utilisateur à l'article d'aide www.samplewebsite.com/help/faq  

Client : Je ne peux pas me connecter à mon compte.  
Agent :  
```

## Génération de code spécifique - Utilisez des "mots clés" pour orienter le modèle vers un schéma particulier  
#### Moins efficace ❌:  
```
# Écrire une fonction python simple qui  
# 1. Me demande un nombre en mile
# 2. Convertit les miles en kilomètres  
```

Dans cet exemple de code ci-dessous, l'ajout de "import" suggère au modèle qu'il doit commencer à écrire en Python. (De même, "SELECT" est un bon indice pour le début d'une instruction SQL.)  

### Mieux ✅:  
```
# Écrire une fonction python simple qui  
# 1. Me demande un nombre en mile 
# 2. Convertit les miles en kilomètres  
   
import  
```
