# Bonnes pratiques pour l'ingénierie de prompt avec l'API OpenAI
  
> Rédigé par Jessica Shieh  
> https://help.openai.com/en/articles/6654000-best-practices-for-prompt-engineering-with-openai-api  
> _Règles de base et exemples_  
> Note : "{text input here}" est un emplacement réservé pour le texte/narration réel.  
  
  
## Mettez les instructions au début du prompt et utilisez ### ou """ pour séparer l'instruction et le contexte   
#### Moins efficace ❌:  
```
Résumez le texte ci-dessous sous forme de liste de points importants.  
  
{text input here}  
```
  
### Mieux ✅:  
```
Résumez le texte ci-dessous sous forme de liste de points importants.  
  
Texte : """  
{text input here}  
"""  
```
  
  
## Soyez précis, descriptif et aussi détaillé que possible sur le contexte souhaité, le résultat, la longueur, le format, le style, etc.  
Soyez précis sur le contexte, le résultat, la longueur, le format, le style, etc.  
#### Moins efficace ❌:  
```
Écrivez un poème sur OpenAI.  
```
  
### Mieux ✅:  
```
Écrivez un court poème inspirant sur OpenAI, en mettant l'accent sur le lancement récent du produit DALL-E (DALL-E est un modèle ML de texte vers image) dans le style d'un(e) {poète célèbre}.  
```
  
  
## Articulez le format de sortie souhaité à travers des exemples  
#### Moins efficace ❌:  
```
Extraire les entités mentionnées dans le texte ci-dessous. Extraire les quatre types d'entité suivants : noms de société, noms de personnes, sujets et thèmes spécifiques.  
  
Texte : {text}  
```
  
Montrez, et dites - les modèles répondent mieux lorsqu'on leur montre des exigences de format spécifiques. Cela rend également plus facile à comprendre les sorties multiples de manière fiable.  
  
### Mieux ✅:  
```
Extraire les entités importantes mentionnées dans le texte ci-dessous. Extraire d'abord tous les noms de société, puis tous les noms de personnes, puis extraire les sujets spécifiques qui conviennent au contenu et enfin extraire les thèmes généraux qui dominent.  
  
Format désiré :  
Noms de société : <liste_de_noms_de_sociétés_séparés_par_des_virgules>  
Noms de personnes : -||-  
Sujets spécifiques : -||-  
Thèmes généraux : -||-  
  
Texte : {text}  
```
  
  
## Commencez par le zero-shot, puis le few-shot, si aucun des deux ne fonctionne, puis fine-tune (peaufinage)  
### ✅ Zero-shot 
```
Extraire les mots-clés du texte ci-dessous.  
  
Texte : {text}  
  
Mots-clés :  
```
  
### ✅ Few-shot - fournir quelques exemples  
```
Extraire les mots-clés des textes correspondants ci-dessous.  
  
Texte 1 : Stripe fournit des API que les développeurs web peuvent utiliser pour intégrer le traitement des paiements dans leurs sites web et applications mobiles.  
Mots-clés 1 : Stripe, traitement des paiements, API, développeurs web, sites web, applications mobiles  
##  
Texte 2 : OpenAI a formé des modèles de langage de pointe qui sont très bons pour comprendre et générer du texte. Notre API fournit un accès à ces modèles et peut être utilisée pour résoudre virtuellement n'importe quelle tâche.  
Mots-clés 2 : OpenAI, modèles de langage, traitement de texte, API.  
##  
Texte 3 : {text}  
Mots-clés 3 :  
```
  
  
## Réduire les descriptions "floues" et imprécises  
#### Moins efficace ❌:  
```
La description de ce produit devrait être assez courte, seulement quelques phrases, et pas beaucoup plus.  
```
  
### Mieux ✅:  
```
Utiliser un paragraphe de 3 à 5 phrases pour décrire ce produit.  
```
  
  
## Au lieu de dire simplement quoi ne pas faire, dites quoi faire à la place  
#### Moins efficace ❌:  
```
La conversation suivante est entre un agent et un client. NE DEMANDEZ PAS DE NOM D'UTILISATEUR OU DE MOT DE PASSE. NE RÉPÉTEZ PAS.  
  
Client : Je ne peux pas me connecter à mon compte.  
Agent :  
```
  
### Mieux ✅:  
```
La conversation suivante est entre un agent et un client. L'agent essaiera de diagnostiquer le problème et proposera une solution, en s'abstenant de poser des questions liées à PII. Au lieu de demander PII, tel que le nom d'utilisateur ou le mot de passe, renvoyez l'utilisateur à l'article d'aide www.samplewebsite.com/help/faq  
  
Client : Je ne peux pas me connecter à mon compte.  
Agent :  
```
  
  
## Génération de code spécifique - Utilisez des "mots clés" pour orienter le modèle vers un modèle particulier  
#### Moins efficace ❌:  
```
# Écrire une fonction Python simple qui  
# 1. Me demandez un nombre en miles  
# 2. Il convertit les miles en kilomètres  
```
  
Dans cet exemple de code ci-dessous, l'ajout de suggestions d'importation (import) au modèle indique qu'il doit commencer à écrire en Python. (De même, "SELECT" est un bon indice pour le début d'une instruction SQL.)  
  
### Mieux ✅:  
```
# Écrire une fonction Python simple qui  
# 1. Me demandez un nombre en miles  
# 2. Il convertit les miles en kilomètres  
   
import  
```
