# OpenAI APIを使用したプロンプトエンジニアリングのベストプラクティス

> Jessica Shiehによる執筆
> https://help.openai.com/en/articles/6654000-best-practices-for-prompt-engineering-with-openai-api
> _ヒントと例_
> 注意：「{ここにテキスト入力}」は、実際のテキスト/コンテキストのプレースホルダーです。

## 指示を冒頭に入れ、###または"""を使用して指示とコンテキストを分離する

#### 効果が低い ❌：
```
以下のテキストを重要なポイントの箇条書きリストとして要約します。

{ここにテキスト入力}
```

### 効果的 ✅:
```
以下のテキストを重要なポイントの箇条書きリストとして要約します。

テキスト：「」
{ここにテキスト入力}
「」
```

## 希望される文脈、結果、長さ、フォーマット、スタイルなどをできるだけ具体的で記述する

文脈、結果、長さ、フォーマット、スタイルなどを明確にしましょう。

#### 効果が低い ❌：
```
OpenAIについての詩を書いてください。
```

### 効果的 ✅:
```
OpenAIについてのインスピレーションを与えるような短い詩を書いてください。テキストを画像に変換するMLモデルである最近のDALL-E製品のローンチ（DALL-E）に焦点を当て、{有名な詩人}のスタイルで書いてください。
```

## 例を通じて、希望される出力形式を表現しましょう

#### 効果が低い ❌：
```
以下のテキストに言及されているエンティティを抽出します。会社名、人名、特定のトピック、およびテーマの4つのエンティティタイプを抽出してください。

テキスト：{テキスト}
```

表示して説明することで、特定の書式要件が示されると、モデルはより正確に反応します。これにより、複数の出力を可算判別可能にすることも容易になります。

### 効果的 ✅:
```
以下のテキストに言及されている重要なエンティティを抽出してください。まず、すべての企業名を抽出し、次にすべての人名を抽出し、そのコンテンツに適合する特定のトピックを抽出し、最後に一般的な包括的なテーマを抽出します。

望ましい形式：
会社名：<コンマ区切りの会社名のリスト>
人名：-||-
特定のトピック：-||-
一般的なテーマ：-||-

テキスト：{テキスト}
```

## ゼロショットから始めて、フューショット、どちらもうまくいかなかった場合はファインチューニングを行いましょう

### ✅ ゼロショット
```
以下のテキストからキーワードを抽出してください。

テキスト：{テキスト}

キーワード：
```

### ✅ フューショット　-　いくつかの例を提供しましょう
```
以下のテキストからキーワードを抽出してください。

テキスト1：Stripeは、Web開発者がウェブサイトやモバイルアプリケーションに支払い処理を統合するために使用できるAPIを提供しています。
キーワード1：Stripe、支払い処理、API、Web開発者、ウェブサイト、モバイルアプリケーション
##
テキスト2：OpenAIは、非常に理解と生成のテキストのコード化に適した、最新の言語モデルを訓練しています。当社のAPIはこれらのモデルへのアクセスを提供し、言語を処理するタスクを含むほとんどのタスクを解決することができます。
キーワード2：OpenAI、言語モデル、テキスト処理、API。
##
テキスト3：{テキスト}
キーワード3：
```

## 「もう少し詳細に」とか「長すぎないで」という不明確な説明を減らしましょう

#### 効果が低い ❌：
```
この商品の説明は、かなり短く、数文のみで、それ以上ではありません。
```

### 効果的 ✅:
```
3から5文の段落を使用して、この商品を説明します。
```

## 単に何をすべきでないかだけでなく、代わりに何をすべきか説明しましょう

#### 効果が低い ❌：
```
次の会話は、エージェントと顧客の間の会話です。ユーザ名やパスワードを質問しないでください。繰り返さないでください。

顧客：アカウントにログインできません。
エージェント：
```

### 効果的 ✅:
```
次の会話は、エージェントと顧客の間の会話です。Pllに関連する質問はせず、代わりにユーザーをヘルプ記事www.samplewebsite.com/help/faqに導く方法を提案し、問題を診断し、解決策を提案します。

顧客：アカウントにログインできません。
エージェント：
```

## コード生成の指示 - 特定のパターンに向けてモデルを促す「リードワード」を使用しましょう

#### 効果が低い ❌：
```
# 単純なPython関数を作成
# 1.マイルの数を求める
# 2.マイルをキロメートルに変換する

以下に示すコードの例では、モデルがPythonで書き始めるように「インポート」を追加しています。 （同様に、「SELECT」はSQLステートメントの開始に適したヒントです。）

### 効果的 ✅:
```
# 単純なPython関数を作成
# 1.マイルの数を求める
# 2.マイルをキロメートルに変換する

インポート
```
