# OpenAI API와 함께하는 프롬프트 엔지니어링을 위한 최적의 방법

> Jessica Shieh 작성
> https://help.openai.com/en/articles/6654000-best-practices-for-prompt-engineering-with-openai-api
> _Rules of Thumb and Examples_
> 참고 : "{text input here}"는 실제 텍스트 / 컨텍스트를 위한 placeholder입니다.


## 지시 사항은 프롬프트의 시작부에 넣고 ### 또는 """를 사용하여 지시문과 컨텍스트를 분리하십시오
#### 효과 미비 ❌:
```
아래 텍스트를 가장 중요한 지점의 분류점 목록으로 요약하십시오.

{text input here}
```

### 좋은 방법 ✅:
```
아래 텍스트를 가장 중요한 지점의 분류점 목록으로 요약하십시오.

Text: """
{text input here}
"""
```


## 바람직한 문맥, 결과, 길이, 형식, 스타일 등을 가능한 한 구체적으로, 기술적으로, 자세히 기술하십시오.
```이 해결해야 할 컨텍스트, 결과, 길이, 형식, 스타일 등에 대해 구체적으로 설명하십시오.```
#### 효과 미비 ❌:
```
OpenAI에 대한 시를 써 보세요.
```

### 좋은 방법 ✅:
```
{famous poet}의 시적 스타일로, 최근 DALL-E 제품 출시 (DALL-E는 텍스트에서 이미지를 생성하는 ML 모델입니다)에 초점을 맞추어 OpenAI에 대한 짧은 감동적인 시를 쓰십시오.
```


## 예를 통해 원하는 출력 형식을 서술하십시오
#### 효과 미비 ❌:
```
아래의 텍스트에서 언급된 개체를 추출하십시오. 회사명, 인명, 구체적인 주제 및 주제간 관계 중 다음 4가지 개체 유형을 추출하십시오.

Text: {text}
```

코드 모델들은 특정 형식 요구 사항을 증명 할 때 더 잘 반응하며, 여러 출력을 신뢰성 있게 프로그램적으로 분석하는 것을 쉽게 만듭니다.

### 좋은 방법 ✅:
```
아래 텍스트에서 중요한 개체를 추출하십시오. 먼저 모든 회사 이름을 추출한 후, 모든 인명을 추출하고 그 다음 내용에 맞는 구체적인 주제를 추출하도록 튜닝하고 마지막으로 일반적인 테마를 추출하십시오.

요구되는 형식:

회사 이름: <comma_separated_list_of_company_names>
인명: -||-
구체적인 주제: -||-
일반적인 테마: -||-

Text: {text}
```


## 제로샷으로 시작하고, 퓨샷으로 시도해보세요. 둘 다 작동하지 않으면 파인튜닝을 시도해보십시오.
### ✅ 제로샷  
```
아래 텍스트에서 키워드를 추출하십시오.

Text: {text}

키워드:
```

### ✅ 퓨샷 - 몇 가지 예를 제공하십시오.
```
아래 해당 텍스트에서 키워드를 추출하십시오.

Text 1: Stripe는 웹 개발자가 웹사이트와 모바일 애플리케이션에 결제 처리를 통합할 수 있는 API를 제공합니다.
Keywords 1: Stripe, 결제 처리, API, 웹 개발자, 웹사이트, 모바일 애플리케이션
##
Text 2: OpenAI는 이해와 텍스트 생성을 매우 능숙하게 수행하는 최신 언어 모델을 훈련시켰습니다. 우리 API는 이러한 모델에 액세스할 수 있으며 언어를 처리하는 거의 모든 작업을 해결하는 데 사용할 수 있습니다.
Keywords 2: OpenAI, 언어 모델, 텍스트 처리, API.
##
Text 3: {text}
Keywords 3:
```


## "허름한" 및 정확하지 않은 설명을 줄이십시오.
#### 효과 미비 ❌:
```
이 제품에 대한 설명은 상당히 짧아야하며, 몇 문장 정도면 충분하며, 이보다 더 많아서는 안됩니다.
```

### 좋은 방법 ✅:
```
이 제품을 설명하는 3~5 문장의 문단을 사용하십시오.
```


## 단지 무엇을 하지 말고 그 대신에 어떻게 할지 설명하십시오.
#### 효과 미비 ❌:
```
다음은 에이전트와 고객 간의 대화입니다. USERNAME 또는 PASSWORD를 묻지 마십시오. 반복하지 마십시오.

고객 : 내 계정으로 로그인 할 수 없습니다.
에이전트 : 
```

### 좋은 방법 ✅:
```
다음은 에이전트와 고객 간의 대화입니다. 에이전트는 PII와 관련된 모든 질문을 하지 않은 채 문제를 진단하고 해결책을 제안하려 할 것입니다. USERNAME 또는 PASSWORD와 같은 PII 대신 www.samplewebsite.com/help/faq에 사용자를 참조하십시오.

고객 : 내 계정으로 로그인 할 수 없습니다.
에이전트 :
```


## 코드 생성 구체적 - "선두 단어"를 사용하여 모델을 특정 패턴으로 유도하십시오.
#### 효과 미비 ❌:
```
# 최대한 간단한 파이썬 함수를 작성하십시오.
# 1. 마일에서 숫자를 입력합니다.
# 2. 마일에서 킬로미터로 변환합니다.
```

아래 코드 예제에서 "import"를 추가하면 모델이 Python으로 작성을 시작해야 할 것으로 추정됩니다. (마찬가지로 "SELECT"는 SQL 문의 시작을 나타내는 좋은 힌트입니다.)

### 좋은 방법 ✅:
```
# 최대한 간단한 파이썬 함수를 작성하십시오.
# 1. 마일에서 숫자를 입력합니다.
# 2. 마일에서 킬로미터로 변환합니다.

import
```
