# OpenAI API ile hızlı mühendisliğin en iyi yöntemleri

> Jessica Shieh tarafından yazılmıştır  
> https://help.openai.com/en/articles/6654000-best-practices-for-prompt-engineering-with-openai-api  
> _Kural ve örnekler_  
> Not: "{text input here}" gerçek metin / bağlama yer tutucusudur  

## Talimatları başa koyun ve talimat ve bağlamı ### veya """ ile ayırın.  
#### Az etkili ❌:  
```
Aşağıdaki metni en önemli noktaları madde olarak özetleyin.  
  
{text input here}  
```
  
### Daha iyi ✅:  
```
Aşağıdaki metni en önemli noktaları madde olarak özetleyin.  
  
Metin: """  
{text input here}  
"""  
```
  
  
## Daha fazla bağlamsal bilgi, sondaki çıktı formatını sağlama  
Bağlam, çıktı formatı, uzunluk, stil vb. konularda mümkün olduğunca spesifik, açıklayıcı ve detaylı olun  
  
#### Az etkili ❌:  
```
OpenAI hakkında bir şiir yazın.  
```
  
### Daha iyi ✅:  
```
OpenAI hakkında kısa, ilham verici bir şiir yazın ,(DALL-E bir metin-görüntü ML modelidir) {famous poet} stilinde, son zamanlarda piyasaya sürülen DALL-E ürün lansmanına odaklanarak.  
```
  
  
## Çıktı formatını örneklerle dile getirin  
#### Az etkili ❌:  
```
Aşağıdaki metinde geçen varlıkları çıkarın. Şirket adları, kişi adları, özel konular ve temalar dahil 4 varlık türünü ayrıştırın.  
  
Metin: {text}  
```
  
Gösterin ve anlatın - modeller belirli format gereksinimleri gösterildiğinde daha iyi yanıt verir. Bu, program açısından birden fazla çıktıyı güvenilir bir şekilde ayrıştırmayı da daha kolay hale getirir.  
  
### Daha iyi ✅:  
```
Aşağıdaki metinde geçen önemli varlıkları çıkarın. İlk olarak, tüm şirket adlarını çıkarın, ardından tüm kişi adlarını çıkartın, sonra içeriğe uygun belirli konuları çıkarın ve nihayetinde genel, kapsayıcı temaları çıkarın.  
  
İstenen format:  
Şirket adları: <virgülle_ayrılmış_şirket_adları_listesi>  
Kişi adları: -||-  
Özel konular: -||-  
Genel temalar: -||-  
  
Metin: {text}  
```
  
  
## Sıfır-Atışlı başlayın, daha sonra birkaç kez sıkıştırın, hiçbiri işe yaramaz, daha sonra ince ayar yapın  
### ✅ Sıfır-Atışlı başlayın  
```
Aşağıdaki metinden anahtar kelimeleri çıkarın.  
  
Metin: {text}  
  
Anahtar kelimeler:  
```
  
### ✅ Birkaç kez sıkıştırın - birkaç örnek sağlayın  
```
Aşağıdaki metinlerden anahtar kelimeleri çıkarın.  
  
Metin 1: Stripe, ödeme işleme API'larını web sitelerine ve mobil uygulamalara entegre etmek için kullanabilen web geliştiricilere sağlar.    
Anahtar Kelimeler 1: Stripe, ödeme işlemcisi, API'lar, web geliştiricileri, web siteleri, mobil uygulamalar  
##  
Metin 2: OpenAI, çok iyi anlama ve metin oluşturma yeteneğine sahip en son dil modelleri eğitmiştir. API'miz bu modellere erişim sağlar ve dil işleme içeren neredeyse her görevi çözmek için kullanılabilir.  
Anahtar Kelimeler 2: OpenAI, dil modelleri, metin işleme, API.  
##  
Metin 3: {text}  
Anahtar Kelimeler 3:  
```
  
  
## “Pamuklu” ve kesin olmayan açıklamaları azaltın  
#### Az etkili ❌:  
```
Bu ürünün tanımı oldukça kısa, sadece birkaç cümle ve fazla değil.  
```
  
### Daha iyi ✅:  
```
Bu ürünü tanımlamak için 3 ila 5 cümlelik bir paragraf kullanın.  
```
  
  
## Sadece ne yapmamız gerektiğini değil, ne yapılması gerektiğini söyleyin  
#### Az etkili ❌:  
```
Aşağıdaki konuşma bir Temsilci ve Bir Müşteri arasındadır. KULLANICI ADI VE ŞİFRE SORMAYIN. TEKRAR ETMEYİN.  
  
Müşteri: Hesabıma giremiyorum.  
Temsilci:  
```
  
### Daha iyi ✅:  
```
Aşağıdaki konuşma bir Temsilci ve Bir Müşteri arasındadır. Temsilci sorunu teşhis etmeye çalışacak ve çözüm önerisi sunacaktır; kişisel bilgi içermeyecek şekilde. Kullanıcı adı veya parola gibi kişisel bilgi yerine, kullanıcıyı www.samplewebsite.com/help/faq adresindeki yardım makalesine yönlendirin.  
  
Müşteri: Hesabıma giremiyorum.  
Temsilci:  
```
  
  
## Kod üretimi özel - Modeli belirli bir desene yönlendirmek için "önde gelen kelime" kullanın  
#### Az etkili ❌:  
```
#Basit bir Python işlevi yazın  
# 1. Bana bir milde bir sayı sormayı sorun  
# 2. Bununla mil'i kilometreye dönüştürün  
```
  
Aşağıdaki kod örneğinde, "import" ekleyerek modeli Python'da yazmaya başlaması gerektiğine yönlendiriyoruz. ("SELECT" de bir SQL ifadesinin başlangıcı için iyi bir ipucu.)  
  
### Daha iyi ✅:  
```
#Basit bir Python işlevi yazın  
# 1. Bana bir milde bir sayı sormayı sorun  
# 2. Bununla mil'i kilometreye dönüştürün  
   
import  
```
