# OpenAI API最佳提示实践

> 作者：Jessica Shieh  
> https://help.openai.com/zh/articles/6654000-best-practices-for-prompt-engineering-with-openai-api  
> _实践规则和示例_  
> 注："{text input here}"是实际文本/背景的占位符

## 在提示开始处放置说明，并使用###或"""分隔说明和内容

#### 不太有效 ❌：

```
将以下文本总结为最重要的要点的项目符号列表。

{text input here}
```

### 更好的做法 ✅：

```
将以下文本总结为最重要的要点的项目符号列表：

Text： """
{text input here}
"""
```

## 尽可能明确地描述所需的上下文、结果、长度、格式、样式等

关于上下文、结果、长度、格式、样式等要具体、描述得详细。

#### 不太有效 ❌： 
```
写一首描写OpenAI的诗。
```

### 更好的做法 ✅： 
```
写一首以{famous poet}的风格，专注于最近的DALL-E产品推出（DALL-E是一种文本到图像ML模型）的启发性的OpenAI的诗。
```

## 通过示例来说明所需的输出格式

#### 不太有效 ❌:
```
从以下文本中提取提到的实体。提取以下4种实体类型：公司名称、人名、特定主题和主题。
Text: {text}
```

展示和说明-当给定具体格式需求时，模型的响应更好。这也使得在程序上可靠地解析多个输出更容易。

### 更好的做法 ✅：
```
从以下文本中提取重要的实体。首先提取所有公司名称，然后提取所有人名，然后提取适合内容的特定主题，最后提取一般的概述性主题

期望格式：
公司名称：<逗号分隔的公司名称列表>
人名： -||
具体主题： -||
一般主题： -||-

文本：{text}
```

## 先从零开始，然后再尝试少量的训练，如果都不行，就进行微调

### ✅ 零-shot  
```
从以下文本中提取关键字。

文本 {text}

关键字：
```

### ✅ 少-shot-提供一些示例
```
从以下相关文本中提取关键字。

文本1：Stripe提供API，网页开发者可以将其集成到网站和移动应用程序中，实现付款处理。

关键字1：Stripe、支付处理、API、网页开发人员、网站、移动应用程序。
##

文本2：OpenAI已经训练过先进的语言模型，非常擅长理解和生成文本。我们的API提供对这些模型的访问，并可用于解决几乎涉及处理语言的任何任务。

关键字2：OpenAI、语言模型、文本处理、API。
##

文本3：{text}

关键字3：
```

## 减少“蓬松”和不精确的描述

#### 不太有效 ❌：  
```
此产品的描述应该相当短，只有几句话，不要太多。
```

### 更好的做法 ✅：  
``` 
使用3到5句话的段落来描述此产品。
```

## 不要只说不能做什么，要说明应该做什么

#### 不太有效 ❌：  
```
以下是代理和客户之间的对话。不要询问用户名或密码。不要重复。

客户：我无法登录我的帐户。
代理：
```

### 更好的做法 ✅：
  
```
以下是代理和客户之间的对话。代理将尝试诊断问题并提出解决方案，同时避免询问与PII相关的任何问题。不要问PII，如用户名或密码，而是将用户转到www.samplewebsite.com/help/faq上的帮助文章。

客户：我无法登录我的帐户。
代理:
```

## 代码生成特定-使用“前置引导单词”来促使模型朝着特定的模式写入

#### 不太有效 ❌：

```
# 写一个简单的python函数，  
# 1.向我询问英里数  
# 2.将英里转换为公里  
```

在下面的代码示例中，添加"import"提示，提示模型应该开始用Python编写。（同样，"SELECT"是SQL语句开头的好提示。）

### 更好的做法 ✅： 
```python
# 写一个简单的python函数，  
# 1.向我询问英里数  
# 2.将英里转换为公里  

import  
```
