# OpenAI API最佳提示工程實踐

> 撰寫：Jessica Shieh
> https://help.openai.com/zh-hant/articles/6654000-openai-api%E6%9C%80%E4%BD%B3%E6%8F%90%E7%A4%BA33
> **準則和範例**
> 註："{ 文本輸入 這裡 }" 是實際文本/內容的佔位符

## 將指示放在提示的開始，使用###或"""將指示和內容分開
#### 不夠有效 ❌：
```
將下面的文本總結為最重要的要點的項目列表。

{ 文本輸入 這裡 } 
```

### 更好✅：
```
將下面的文本總結為最重要的要點的項目列表。

文本：""" 
{ 文本輸入 這裡 } 
""" 
```

## 對期望的上下文，結果，長度，格式，風格等進行具體，描述和盡可能詳細
對上下文、結果、長度、格式、風格等進行具體描述
#### 不夠有效 ❌：
```
寫一首關於OpenAI的詩。

```

### 更好 ✅：
```
寫一首短小而鼓舞人心的詩，關注最近的DALL-E產品推出（DALL-E是一種文本到圖像的機器學習模型），以{ 著名詩人 }風格創作。
```

## 通過示例說明期望的輸出格式
#### 不夠有效 ❌：
```
從以下文本中提取提到的實體。從以下4種實體類型中提取：公司名稱，人名，具體主題和主題。

文本：{ 文本輸入 這裡 } 
```

秀出來，告訴機器模型特定的格式要求能更好的使用模型。這樣做可以更容易地以可靠的方式解析出多個輸出。
### 更好✅：
```
提取以下文本中提到的重要實體。首先提取所有公司名稱，然後提取所有人名，然後提取符合內容的特定主題，最後提取一般的橫跨所有主題。

所需格式：
公司名稱：<逗號分隔的公司名稱列表>
人名：-||-
具體主題：-||-
通用主題：-||-

文本：{ 文本輸入 這裡 } 
```

## 從零開始入手，然後從少量示範中開始，如果兩者都不起作用，則進行進一步調整
### ✅從零開始
```
從以下文本中提取關鍵詞。

文本：{ 文本輸入 這裡 } 

關鍵詞：
```

### ✅從幾個示例開始 - 提供幾個示例
```
從以下相應的文本中提取關鍵詞。

文本1：Stripe提供API，供Web開發人員將付款處理整合到他們的網站和移動應用程序中。
關鍵詞1：Stripe，付款處理，API，Web開發人員，網站，移動應用程序。

文本2：OpenAI已經訓練了尖端的語言模型，這些模型在理解和生成文字方面非常出色。我們的API提供對這些模型的訪問，可用於解決幾乎涉及處理語言的任務。
關鍵詞2：OpenAI，語言模型，文字處理，API。

文本3：{ 文本輸入 這裡 } 
關鍵詞3： 
```

## 減少“蓬鬆”的描述
#### 不夠有效 ❌：
```
該產品的描述應該相當簡短，僅限幾句話，不要太多。
```

### 更好 ✅：
```
使用3-5句的段落來描述此產品。
```

## 代替只說什麼不做，請說代替做什麼
#### 不夠有效 ❌：
```
下面是代理和客戶之間的一次對話。不要問用戶名或密碼。不要重複。

客戶：我無法登錄我的帳戶。
代理： 
```

### 更好 ✅：
```
以下是代理和客戶之間的對話。代理將嘗試診斷問題並提出解決方案，同時避免提出任何與PII有關的問題。代替問成P11，例如用戶名或密碼，請將用戶參考到幫助文檔www.samplewebsite.com/help/faq

客戶：我無法登錄我的帳戶。
代理： 
```

## 代碼生成具體適用_使用“前導詞”來引導模型朝特定的模式前進
#### 不夠有效 ❌：
```
# 寫一個簡單的Python函數，該函數
# 1. 請我輸入英哩數字
# 2. 它將英里轉換成公里
```

在以下代碼示例中，添加“導入”提示，以使模型開始在Python中編寫。（同樣，“SELECT”是開始SQL語句的好提示。）  
### 更好✅：
```
# 寫一個簡單的Python函數，該函數
# 1. 請我輸入英哩數字
# 2. 它將英里轉換成公里

import
```
